StructuredQrError

Enum StructuredQrError 

pub enum StructuredQrError {
    AtLeast2Pieces,
    TotalMismatch(usize),
    MissingParts,
    Parity,
    TooShort,
    StructuredWrongMode,
    StructuredWrongEnc,
    SeqGreaterThanTotal(u8, u8),
    LengthMismatch(usize, usize),
    UnsupportedVersion(i16),
    SplitMax16(usize),
}
Error variants regarding structured append

Variants



AtLeast2Pieces

Structured append mode should contain at least two qrcodes



TotalMismatch(usize)

Encoded number of pieces does not match real number of pieces



MissingParts

Not all the QR codes parts are present



Parity

Computed parity byte does not match



TooShort

QR code data shorter than 5 bytes



StructuredWrongMode

QR code mode is not structured append



StructuredWrongEnc

QR code encoding is not the one supported in structured append



SeqGreaterThanTotal(u8, u8)

QR code sequence number is greater than total



LengthMismatch(usize, usize)

QR code length mismatch



UnsupportedVersion(i16)

Unsupported version



SplitMax16(usize)

Maximum supported pieces in structured append is 16