[−][src]Module qr_code::types
Type to support QR code encoding
Enums
| Color | The color of a module. |
| EcLevel | The error correction level. It allows the original information be recovered even if parts of the code is damaged. |
| Mode | The mode indicator, which specifies the character set of the encoded data. |
| QrError |
|
| Version | In QR code terminology, |
Type Definitions
| QrResult |
|